@@ -130,6 +130,114 @@ ordfactanalpost (double* sam, const int* samrow, const int* samcol,
     
 
     
+
+
+    // sample Lambda
+    for (int i=0; i<K; ++i){
+      Matrix<double> free_indic = t(Lambda_free_indic(i,_));
+      Matrix<double> not_free_indic = (free_indic-1)*-1;
+      if (sumc(free_indic)[0] > 0 && 
+	  sumc(not_free_indic)[0] > 0){ // both constrnd & unconstrnd
+	Matrix<double> phifree_i =  t(selif(t(phi), free_indic));
+	Matrix<double> mulamfree_i = selif(t(Lambda_prior_mean(i,_)), 
+					   free_indic); // prior mean
+	Matrix<double> hold = selif(t(Lambda_prior_prec(i,_)), 
+				    free_indic);
+	Matrix<double> sig2lamfree_inv_i = 
+	  eye<double>(hold.rows());   // prior prec
+	for (int j=0; j<(hold.rows()); ++j)
+	  sig2lamfree_inv_i(j,j) = hold[j];
+	Matrix<double> Lambdacon_i = selif(t(Lambda(i,_)), not_free_indic);
+	Matrix<double> phicon_i  = t(selif(t(phi), not_free_indic));
+	
+	Matrix<double> newX_i = Xstar(_,i) - phicon_i*Lambdacon_i; 
+	Matrix<double> Lam_post_var = invpd(sig2lamfree_inv_i + 
+					    t(phifree_i) * phifree_i); 
+	Matrix<double> Lam_post_C = cholesky(Lam_post_var);
+	Matrix<double> Lam_post_mean = Lam_post_var * 
+	  (sig2lamfree_inv_i * mulamfree_i + t(phifree_i) * newX_i);
+	
+	Matrix<double> Lambdafree_i = 
+	  gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
+	
+	// check to see if inequality constraints hold
+	Matrix<double> Lambda_ineq_vec = Lambda_ineq(i,_);
+	double ineq_holds = 0;
+	int Lam_count = 0;
+	for (int j=0; j<D; ++j){
+	  if (free_indic[j]==1)
+	    ineq_holds = std::min(ineq_holds, 
+				  Lambda_ineq_vec[j]*Lambdafree_i[Lam_count]);
+	  ++Lam_count;
+	}
+	while (ineq_holds < 0){
+	  Lambdafree_i = 
+	    gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
+	  Lam_count = 0;
+	  double test = 0;
+	  for (int j=0; j<D; ++j){
+	    if (free_indic[j]==1){
+	      Matrix<double> prodcheck = 
+		Lambda_ineq_vec[j]*Lambdafree_i[Lam_count];    
+	      test = std::min(test, prodcheck[0]); 	      
+	      ++Lam_count;
+	    }
+	  }
+	  ineq_holds = test;
+	}
+	
+	// put draw into Lambda 
+	Lam_count = 0;
+	for (int j=0; j<D; ++j){
+	  if (free_indic[j] == 1){
+	    Lambda(i,j) = Lambdafree_i[Lam_count];
+	    ++Lam_count;
+	  }
+	}
+      }
+      else  if (sumc(free_indic)[0] > 0){ // just unconstrained
+	Matrix<double> phifree_i =  t(selif(t(phi), free_indic));
+	Matrix<double> mulamfree_i = selif(t(Lambda_prior_mean(i,_)), 
+					   free_indic); // prior mean
+	Matrix<double> hold = selif(t(Lambda_prior_prec(i,_)), free_indic);
+	Matrix<double> sig2lamfree_inv_i = 
+	  eye<double>(hold.rows());  // prior prec
+	for (int j=0; j<hold.rows(); ++j)
+	  sig2lamfree_inv_i(j,j) = hold[j];
+	Matrix<double> Lam_post_var = invpd(sig2lamfree_inv_i + 
+					    t(phifree_i) * phifree_i); 
+	Matrix<double> Lam_post_C = cholesky(Lam_post_var);
+	Matrix<double> Lam_post_mean = Lam_post_var * 
+	  (sig2lamfree_inv_i * mulamfree_i + t(phifree_i) * Xstar(_,i));
+	Matrix<double> Lambdafree_i = 
+	  gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
+	
+	// check to see if inequality constraints hold
+	Matrix<double> Lambda_ineq_vec = Lambda_ineq(i,_);
+	double ineq_holds = 0;
+	for (int j=0; j<D; ++j){
+	  ineq_holds = 
+	    std::min(ineq_holds, Lambda_ineq_vec[j]*Lambdafree_i[j]);
+	}
+	while (ineq_holds < 0){
+	  Lambdafree_i = 
+	    gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
+	  double test = 0;
+	  for (int j=0; j<D; ++j){
+	    double prodcheck = Lambda_ineq_vec[j]*Lambdafree_i[j];
+	    test = std::min(test, prodcheck); 
+	  }
+	  ineq_holds = test;
+	}
+	
+	// put draw into Lambda
+	for (int j=0; j<D; ++j){
+	  Lambda(i,j) = Lambdafree_i[j];
+	}
+      }	
+    }      
+    
+
     // sample gamma
     for (int j=0; j<K; ++j){ // do the sampling for each manifest var
       Matrix<double> X_mean = phi * t(Lambda(j,_));
@@ -192,121 +300,12 @@ ordfactanalpost (double* sam, const int* samrow, const int* samcol,
 
 
 
-    // sample Lambda
-    for (int i=0; i<K; ++i){
-      Matrix<double> free_indic = t(Lambda_free_indic(i,_));
-      Matrix<double> not_free_indic = (free_indic-1)*-1;
-      if (sumc(free_indic)[0] > 0 && 
-	  sumc(not_free_indic)[0] > 0){ // both constrnd & unconstrnd
-	Matrix<double> phifree_i =  t(selif(t(phi), free_indic));
-	Matrix<double> mulamfree_i = selif(t(Lambda_prior_mean(i,_)), 
-					   free_indic); // prior mean
-	Matrix<double> hold = selif(t(Lambda_prior_prec(i,_)), 
-				    free_indic);
-	Matrix<double> sig2lamfree_inv_i = 
-	  eye<double>(hold.rows());   // prior prec
-	for (int j=0; j<(hold.rows()); ++j)
-	  sig2lamfree_inv_i(j,j) = hold[j];
-	Matrix<double> Lambdacon_i = selif(t(Lambda(i,_)), not_free_indic);
-	Matrix<double> phicon_i  = t(selif(t(phi), not_free_indic));
-	
-	Matrix<double> newX_i = Xstar(_,i) - phicon_i*Lambdacon_i; 
-	Matrix<double> Lam_post_var = invpd(sig2lamfree_inv_i + 
-					    t(phifree_i) * phifree_i); 
-	Matrix<double> Lam_post_C = cholesky(Lam_post_var);
-	Matrix<double> Lam_post_mean = Lam_post_var * 
-	  (sig2lamfree_inv_i * mulamfree_i + t(phifree_i) * newX_i);
-	
-	Matrix<double> Lambdafree_i = 
-	  gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
-	
-	// check to see if inequality constraints hold
-	Matrix<double> Lambda_ineq_vec = Lambda_ineq(i,_);
-	double ineq_holds = 0;
-	int Lam_count = 0;
-	for (int j=0; j<D; ++j){
-	  if (free_indic[j]==1)
-	    ineq_holds = std::min(ineq_holds, 
-				  Lambda_ineq_vec[j]*Lambdafree_i[Lam_count]);
-	}
-	while (ineq_holds < 0){
-	  Lambdafree_i = 
-	    gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
-	  Lam_count = 0;
-	  double test = 0;
-	  for (int j=0; j<D; ++j){
-	    if (free_indic[j]==1){
-	      Matrix<double> prodcheck = 
-		Lambda_ineq_vec[j]*Lambdafree_i[Lam_count];    
-	      test = std::min(test, prodcheck[0]); 	      
-	    }
-	    ++Lam_count;
-	  }
-	  ineq_holds = test;
-	}
-	
-	// put draw into Lambda 
-	Lam_count = 0;
-	for (int j=0; j<D; ++j){
-	  if (free_indic[j] == 1){
-	    Lambda(i,j) = Lambdafree_i[Lam_count];
-	    ++Lam_count;
-	  }
-	}
-      }
-      else  if (sumc(free_indic)[0] > 0){ // just unconstrained
-	Matrix<double> phifree_i =  t(selif(t(phi), free_indic));
-	Matrix<double> mulamfree_i = selif(t(Lambda_prior_mean(i,_)), 
-					   free_indic); // prior mean
-	Matrix<double> hold = selif(t(Lambda_prior_prec(i,_)), free_indic);
-	Matrix<double> sig2lamfree_inv_i = 
-	  eye<double>(hold.rows());  // prior prec
-	for (int j=0; j<hold.rows(); ++j)
-	  sig2lamfree_inv_i(j,j) = hold[j];
-	Matrix<double> Lam_post_var = invpd(sig2lamfree_inv_i + 
-					    t(phifree_i) * phifree_i); 
-	Matrix<double> Lam_post_C = cholesky(Lam_post_var);
-	Matrix<double> Lam_post_mean = Lam_post_var * 
-	  (sig2lamfree_inv_i * mulamfree_i + t(phifree_i) * Xstar(_,i));
-	Matrix<double> Lambdafree_i = 
-	  gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
-	
-	// check to see if inequality constraints hold
-	Matrix<double> Lambda_ineq_vec = Lambda_ineq(i,_);
-	double ineq_holds = 0;
-	int Lam_count = 0;
-	for (int j=0; j<D; ++j){
-	  ineq_holds = 
-	    std::min(ineq_holds, Lambda_ineq_vec[j]*Lambdafree_i[j]);
-	}
-	while (ineq_holds < 0){
-	  Lambdafree_i = 
-	    gaxpy(Lam_post_C, rnorm(hold.rows(), 1), Lam_post_mean);
-	  Lam_count = 0;
-	  double test = 0;
-	  for (int j=0; j<D; ++j){
-	    double prodcheck = Lambda_ineq_vec[j]*Lambdafree_i[Lam_count];
-	    test = std::min(test, prodcheck); 
-	    ++Lam_count;
-	  }
-	  ineq_holds = test;
-	}
-	
-	// put draw into Lambda
-	Lam_count = 0;
-	for (int j=0; j<D; ++j){
-	  Lambda(i,j) = Lambdafree_i[Lam_count];
-	  ++Lam_count;
-	}
-      }	
-    }      
-    
     
     // print results to screen
     if (verbose[0] == 1 && iter % 500 == 0 && outswitch[0] == 1){
       cout << " MCMCordfactanal Iteration = " << iter << endl;
       cout << " acceptance rate = " << static_cast<double>(accepts[0])/
-	    (static_cast<double>(iter+1)*K) << endl << endl;
+	    (static_cast<double>(iter+1)*K) << endl << endl;      
     }
     if (verbose[0] == 1 && iter % 500 == 0 && outswitch[0] == 2){
       cout << " MCMCirtKd Iteration = " << iter << endl;
